﻿using System;
using System.Windows.Forms;

using DevExpress.XtraEditors;
using DevExpress.XtraMap;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 빙 맵 키
        /// </summary>
        private string bingKey = "INPUT YOUR BING KEY";

        /// <summary>
        /// 맵 컨트롤
        /// </summary>
        private MapControl mapControl;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 동적 미니맵 동작을 설정한다.

            DynamicMiniMapBehavior dynamicMiniMapBehavior = new DynamicMiniMapBehavior();

            #endregion
            #region 미니맵을 설정한다.

            MiniMap miniMap = new MiniMap();

            miniMap.Behavior = dynamicMiniMapBehavior;

            #endregion
            #region 미니맵 빙맵 데이터 공급자를 설정한다.

            BingMapDataProvider miniMapBingMapDataProvider = new BingMapDataProvider();

            miniMapBingMapDataProvider.BingKey = this.bingKey;

            #endregion
            #region 미니맵 이미지 타일 레이어를 설정한다.

            MiniMapImageTilesLayer miniMapImageTilesLayer = new MiniMapImageTilesLayer();

            miniMapImageTilesLayer.DataProvider = miniMapBingMapDataProvider;

            miniMap.Layers.Add(miniMapImageTilesLayer);

            #endregion
            #region 맵 항목 저장소를 설정한다.

            MapItemStorage mapItemStorage = new MapItemStorage();

            #endregion
            #region 미니맵 벡터 항목 레이어를 설정한다.

            MiniMapVectorItemsLayer miniMapVectorItemsLayer = new MiniMapVectorItemsLayer();

            miniMapVectorItemsLayer.Data = mapItemStorage;

            miniMap.Layers.Add(miniMapVectorItemsLayer);

            #endregion
            #region 맵 컨트롤을 설정한다.

            this.mapControl = new MapControl();

            this.mapControl.Name    = "mapControl";
            this.mapControl.Parent  = this.contentPanelControl;
            this.mapControl.Dock    = DockStyle.Fill;
            this.mapControl.MiniMap = miniMap;

            #endregion
            #region 빙 맵 데이터 공급자를 설정한다.

            BingMapDataProvider bingMapDataProvider = new BingMapDataProvider();

            bingMapDataProvider.BingKey = this.bingKey;

            #endregion
            #region 이미지 레이어를 설정한다.

            ImageLayer imageLayer = new ImageLayer();

            imageLayer.DataProvider = bingMapDataProvider;

            this.mapControl.Layers.Add(imageLayer);

            #endregion

            Load += Form_Load;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.mapControl.CenterPoint = new GeoPoint(37.5d, 127d);
            this.mapControl.ZoomLevel   = 10d;
        }

        #endregion
    }
}